==> sds-stylelint-config-0.5.0.tgz: package/src/utils/validatePsuedoState.js <==
const { analyzeFuzzy, removeFromSet } = require('./search');
const metadata = require('../metadata/metadata.js');

/**
 * Validate state
 * @param {Object} obj The object from the first Promise that has valuable information about the custom prop
 * @todo Skip scope validation based on stylelint option
 * @returns {Object} Validation object or definition to skip if not found
 */
const validatePsuedoState = (obj) => {
  if (obj.validate.scope.isGlobal) return { skip: true };
  const results = analyzeFuzzy(obj).filter((item) => item.word);

  if (obj.keys.psuedoState) {
    return { valid: true, received: obj.groups[obj.keys.psuedoState] };
  } else if (obj.fuzzyKeys.size > 0 && results.length > 0) {
    let valid;
    results.map((item) => {
      // fuzzy result already captured previously
      if (item.lastKey && obj.customMessage.length === 1) {
        valid = { skip: true };
      } else if (item.lastKey && results.length === 2) {
        valid = { skip: true };
      } else if (
        (item.lastKey && item.key === obj.keys.attribute + 1) ||
        (item.lastKey && item.key === obj.keys.state + 1)
      ) {
        obj.keys.psuedoState = item.key;
        obj.fuzzyKeys = removeFromSet(obj.fuzzyKeys, obj.keys.psuedoState);
        valid = {
          valid: false,
          expected: metadata.valid.psuedoState,
          received: obj.groups[obj.keys.psuedoState],
        };
      } else {
        valid = { skip: true };
      }
    });
    return valid;
  } else {
    return { skip: true };
  }
};

module.exports = validatePsuedoState;

==> sds-stylelint-config-1.0.1.tgz: package/src/utils/validatePsuedoState.js <==
const { analyzeFuzzy, removeFromSet } = require('./search');
const metadata = require('../metadata/metadata.js');

/**
 * Validate state
 * @param {Object} obj The object from the first Promise that has valuable information about the custom prop
 * @todo Skip scope validation based on stylelint option
 * @returns {Object} Validation object or definition to skip if not found
 */
const validatePsuedoState = (obj) => {
  if (obj.validate.scope.isGlobal || obj.validate.scope.isShared) return { skip: true };
  const results = analyzeFuzzy(obj).filter((item) => item.word);

  if (obj.keys.psuedoState) {
    return { valid: true, received: obj.groups[obj.keys.psuedoState] };
  } else if (obj.fuzzyKeys.size > 0 && results.length > 0) {
    let valid;
    results.map((item) => {
      // fuzzy result already captured previously
      if (item.lastKey && obj.customMessage.length === 1) {
        valid = { skip: true };
      } else if (item.lastKey && results.length === 2) {
        valid = { skip: true };
      } else if (
        (item.lastKey && item.key === obj.keys.attribute + 1) ||
        (item.lastKey && item.key === obj.keys.state + 1)
      ) {
        obj.keys.psuedoState = item.key;
        obj.fuzzyKeys = removeFromSet(obj.fuzzyKeys, obj.keys.psuedoState);
        valid = {
          valid: false,
          expected: metadata.component.valid.psuedoState,
          received: obj.groups[obj.keys.psuedoState],
        };
      } else {
        valid = { skip: true };
      }
    });
    return valid;
  } else {
    return { skip: true };
  }
};

module.exports = validatePsuedoState;
